==> glog-1.00.tar.gz: glog-1.00/month.php <==
<?php
# Show all entries in a month
#
# $Id: month.php,v 1.2 2004/03/11 14:45:16 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	define('PROGRAM', 1);
	include("funcs.php");

	$valid_month = false;
	if (ereg("^([0-9]{4})-([0-9]{2})$", $date, $regs) && count($days) && isset($months[$date])) {
		$year = (int)$regs[1];
		$mon  = (int)$regs[2];
		$valid_month = true;
	}

	$title = "Monthly Archive";
	if ($valid_month)
		$title .= " / {$months_bg[$mon]}, {$year}";

	html_begin($title);

	if ($valid_month) {
		print "<h4>  {$months_bg[$mon]}, {$year}</h4>\n";
		asort($days);
		foreach ($days as $tmp => $tmpdate) {
			if (ereg($date, $tmpdate)) {
				$text = implode('', file(get_filename($tmpdate)));
				print_day($tmpdate, $text);
			}
		}
	} else {
		print "<h5>No entry for this month ($date)</h5><br />\n";
	}

	html_end();
?>

==> glog-2.00.tar.gz: glog-2.00/month.php <==
<?php
# Show all entries in a month
#
# $Id: month.php,v 1.3 2004/05/02 20:36:50 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	define('PROGRAM', 1);
	include("funcs.php");

	$valid_month = false;
	if (ereg("^([0-9]{4})-([0-9]{2})$", $date, $regs) && count($days) && isset($months[$date])) {
		$year = (int)$regs[1];
		$mon  = (int)$regs[2];
		$valid_month = true;
	}

	$title = "Monthly Archive";
	if ($valid_month)
		$title .= " / {$months_txt[$mon]}, {$year}";

	html_begin($title);

	if ($valid_month) {
		print "<h4>  {$months_txt[$mon]}, {$year}</h4>\n";
		asort($days);
		foreach ($days as $tmp => $tmpdate) {
			if (ereg($date, $tmpdate)) {
				$text = implode('', file(get_filename($tmpdate)));
				print_day($tmpdate, $text);
			}
		}
	} else {
		print "<h5>No entry for this month ($date)</h5><br />\n";
	}

	html_end();
?>
